<!DOCTYPE html>
<html>

<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="csrf-token" content="{{ csrf_token() }}">
  <title>
    @if (trim($__env->yieldContent('template_title')))
      @yield('template_title') |
    @endif {{ trans('installer_messages.title') }}
  </title>
  <link rel="icon" type="image/png" href="{{ asset('images/favicon.png') }}" sizes="32x32" />
  <link href="{{ asset('installer/css/style.css') }}" rel="stylesheet" />
  @yield('style')
  <script>
    window.Laravel = <?php echo json_encode([
        'csrfToken' => csrf_token(),
    ]); ?>
  </script>
</head>

<body>
  <div class="master">
    <div class="box">
      <div class="header">
        <h1 class="header__title">@yield('title')</h1>
      </div>
      <ul class="step">
        <li class="step__divider"></li>
        <li class="step__item {{ isActive('Installer.final') }}">
          <i class="step__icon fa fa-server" aria-hidden="true"></i>
        </li>
        <li class="step__divider"></li>
        <li class="step__item {{ isActive('Installer.activate') }}">
          @if (Request::is('install/activate') || Request::is('install/verify') || Request::is('install/environment/wizard') || Request::is('install/environment/classic'))
            <a href="{{ route('Installer.activate') }}">
              <i class="step__icon fa fa-key" aria-hidden="true"></i>
            </a>
          @else
            <i class="step__icon fa fa-key" aria-hidden="true"></i>
          @endif
        </li>
        <li class="step__divider"></li>
        <li class="step__item {{ isActive('Installer.environment') }} {{ isActive('Installer.environmentWizard') }} {{ isActive('Installer.environmentClassic') }}">
          @if (Request::is('install/environment') || Request::is('install/environment/wizard') || Request::is('install/environment/classic'))
            <a href="{{ route('Installer.environment') }}">
              <i class="step__icon fa fa-cog" aria-hidden="true"></i>
            </a>
          @else
            <i class="step__icon fa fa-cog" aria-hidden="true"></i>
          @endif
        </li>
        <li class="step__divider"></li>
        <li class="step__item {{ isActive('Installer.permissions') }}">
          @if (Request::is('install/permissions') || Request::is('install/environment') || Request::is('install/environment/wizard') || Request::is('install/environment/classic'))
            <a href="{{ route('Installer.permissions') }}">
              <i class="step__icon fa fa-key" aria-hidden="true"></i>
            </a>
          @else
            <i class="step__icon fa fa-key" aria-hidden="true"></i>
          @endif
        </li>
        <li class="step__divider"></li>
        <li class="step__item {{ isActive('Installer.requirements') }}">
          @if (Request::is('install') || Request::is('install/requirements') || Request::is('install/permissions') || Request::is('install/environment') || Request::is('install/environment/wizard') || Request::is('install/environment/classic'))
            <a href="{{ route('Installer.requirements') }}">
              <i class="step__icon fa fa-list" aria-hidden="true"></i>
            </a>
          @else
            <i class="step__icon fa fa-list" aria-hidden="true"></i>
          @endif
        </li>
        <li class="step__divider"></li>
        <li class="step__item {{ isActive('Installer.welcome') }}">
          @if (Request::is('install') || Request::is('install/requirements') || Request::is('install/permissions') || Request::is('install/environment') || Request::is('install/environment/wizard') || Request::is('install/environment/classic'))
            <a href="{{ route('Installer.welcome') }}">
              <i class="step__icon fa fa-home" aria-hidden="true"></i>
            </a>
          @else
            <i class="step__icon fa fa-home" aria-hidden="true"></i>
          @endif
        </li>
        <li class="step__divider"></li>
      </ul>
      <div class="main" id="main-content">
        @if (session('message'))
          <p class="alert text-center">
            <strong>
              @if (is_array(session('message')))
                {{ session('message')['message'] }}
              @else
                {{ session('message') }}
              @endif
            </strong>
          </p>
        @endif
        @if (session()->has('errors'))
          <div class="alert alert-danger" id="error_alert">
            <h4>
              <i class="fa fa-fw fa-exclamation-triangle" aria-hidden="true"></i>
              {{ trans('installer_messages.forms.errorTitle') }}
            </h4>
            <ul>
              @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
              @endforeach
            </ul>
          </div>
        @endif
        @yield('container')
      </div>
    </div>
  </div>
  @yield('scripts')
  <script type="text/javascript">
    var x = document.getElementById('error_alert');
    var y = document.getElementById('close_alert');
    if (y) {
      y.onclick = function() {
        x.style.display = "none";
      };
    }

    function btnBusy(e) {
      e.target.children[0].className = "fa fa-spinner fa-spin";
    }

    function changeText() {
      document.getElementById('main-content').innerHTML = '<div class="alert alert-info"><i class="fa fa-cog fa-spin"></i> {!! trans('installer_messages.wait') !!}</div>';
    };
  </script>
</body>

</html>
